@@ -1,7 +1,7 @@
 import unittest
 import numpy as np
 
-from pyspedas.mms import mms_load_mec, mms_load_fgm, mms_load_scm, mms_load_fpi, mms_load_hpca, mms_load_eis, mms_load_feeps, mms_load_edp, mms_load_edi, mms_load_aspoc, mms_load_dsp
+from pyspedas.mms import mms_load_state, mms_load_mec, mms_load_fgm, mms_load_scm, mms_load_fpi, mms_load_hpca, mms_load_eis, mms_load_feeps, mms_load_edp, mms_load_edi, mms_load_aspoc, mms_load_dsp
 from pyspedas.utilities.data_exists import data_exists
 from pyspedas.mms.hpca.mms_hpca_calc_anodes import mms_hpca_calc_anodes
 from pyspedas.mms.hpca.mms_hpca_spin_sum import mms_hpca_spin_sum
@@ -10,6 +10,24 @@ from pytplot import get_data, del_data
 
 from pyspedas import tdpwrspc
 
+class StateLoadTestCases(unittest.TestCase):
+    def test_load_eph_no_update(self):
+        data = mms_load_state(datatypes=['pos', 'vel']) # ensure the files are stored locally
+        del_data('*') # remove the current tplot vars
+        data = mms_load_state(datatypes=['pos', 'vel'], no_update=True) # ensure the files are stored locally
+        self.assertTrue(data_exists('mms1_defeph_pos'))
+        self.assertTrue(data_exists('mms1_defeph_vel'))
+
+    def test_load_eph_data(self):
+        data = mms_load_state(datatypes=['pos', 'vel'])
+        self.assertTrue(data_exists('mms1_defeph_pos'))
+        self.assertTrue(data_exists('mms1_defeph_vel'))
+
+    def test_load_att_data(self):
+        data = mms_load_state(trange=['2015-10-16', '2015-10-16/06:00'], datatypes=['spinras', 'spindec'])
+        self.assertTrue(data_exists('mms1_defatt_spinras'))
+        self.assertTrue(data_exists('mms1_defatt_spindec'))
+
 ############### DSP ############### 
 class DSPLoadTestCases(unittest.TestCase):
     # def test_load_default_data(self):
@@ -193,15 +211,15 @@ class EDILoadTestCases(unittest.TestCase):
 class ASPOCLoadTestCases(unittest.TestCase):
     def test_load_default_data(self):
         data = mms_load_aspoc(trange=['2015-10-16', '2015-10-16/01:00'])
-        self.assertTrue(data_exists('mms1_aspoc_ionc'))
+        self.assertTrue(data_exists('mms1_aspoc_ionc_l2'))
 
     def test_load_spdf_data(self):
         data = mms_load_aspoc(trange=['2015-10-16', '2015-10-16/01:00'], spdf=True)
-        self.assertTrue(data_exists('mms1_aspoc_ionc'))
+        self.assertTrue(data_exists('mms1_aspoc_ionc_l2'))
 
     def test_load_suffix(self):
         data = mms_load_aspoc(trange=['2015-10-16', '2015-10-16/01:00'], suffix='_test')
-        self.assertTrue(data_exists('mms1_aspoc_ionc_test'))
+        self.assertTrue(data_exists('mms1_aspoc_ionc_l2_test'))
 
 ############### EDP ############### 
 class EDPLoadTestCases(unittest.TestCase):
@@ -234,6 +252,14 @@ class EDPLoadTestCases(unittest.TestCase):
 
 ############### FGM ############### 
 class FGMLoadTestCases(unittest.TestCase):
+    def test_regression_multi_imports_spdf(self):
+        data = mms_load_fgm(data_rate='brst', trange=['2015-10-16/13:06', '2015-10-16/13:10'], spdf=True)
+        t1, d1 = get_data('mms1_fgm_b_gse_brst_l2')
+        data = mms_load_fgm(data_rate='brst', trange=['2015-10-16/13:06', '2015-10-16/13:10'], spdf=True)
+        t2, d2 = get_data('mms1_fgm_b_gse_brst_l2')
+        self.assertTrue(t1.shape == t2.shape)
+        self.assertTrue(d1.shape == d2.shape)
+
     def test_load_default_data(self):
         data = mms_load_fgm(trange=['2015-10-16', '2015-10-16/01:00'])
         self.assertTrue(data_exists('mms1_fgm_b_gse_srvy_l2'))
